@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.7 2007/11/19 14:18:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_AdmOperationLst.php,v 1.8 2008/01/15 09:19:04 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_AdmOperationLst extends SyL_AdmOperation
@@ -72,6 +72,8 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
         // ץDBƤ
         $data_sources = $this->form->getDataSources();
 
+        $conn =& $this->dao->getConnection();
+
         // ơ֥륪֥Ⱥ롼
         $tables = array();
         $option_tmp_column = 'ADM_OPTION_COLUMN';
@@ -107,7 +109,7 @@ class SyL_AdmOperationLst extends SyL_AdmOperation
                     }
                 } else {
                     if (($value !== null) && ($value !== '')) {
-                        $conditions->addLike($column, '%' . $this->conn->escapeLike($value) . '%');
+                        $conditions->addLike($column, '%' . $conn->escapeLike($value) . '%');
                     }
                 }
             } 
