@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.20 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.19 2007/08/27 06:00:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ConfigFilters.php,v 1.20 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ConfigFilters extends SyL_Config
@@ -64,7 +64,7 @@ class SyL_ConfigFilters extends SyL_Config
      * @access private
      * @var string
      */
-    var $filter_event_pre_action = 'executeStream';
+    var $filter_event_pre_action = 'loadStream';
     /**
      * ե륿٥ȡʥ
      * 
