@@ -27,22 +27,27 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.7 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
 /**
- * ꥯȥǡݻ饹
+ * JavaScriptǡݻ饹
+ */
+require_once 'SyL_DataJs.php';
+
+/**
+ * ǡݻ饹
  * 
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_DataWeb.php,v 1.6 2008/01/15 09:19:04 seasonstream Exp $
+ * @version   CVS: $Id: SyL_DataWeb.php,v 1.7 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
-class SyL_DataWeb extends SyL_Data
+class SyL_DataWeb extends SyL_DataJs
 {
     /**
      * ѥ᡼get᥽åɤǼǤե饰
