@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.14 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.15 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,22 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.14 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorCmd.php,v 1.15 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorCmd extends SyL_Error
 {
+    /**
+     * 404 Not Found ɽ
+     *
+     * @access public
+     */
+    function forward404Detail()
+    {
+        echo "Action File Not Found\n";
+        exit;
+    }
+
     /**
      * Ķ̥顼
      * 
