@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.7 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,11 +39,25 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ErrorXmlrpc.php,v 1.7 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ErrorXmlrpc extends SyL_Error
 {
+    /**
+     * 404 Not Found ɽ
+     *
+     * @access public
+     */
+    function forward404Detail()
+    {
+        SyL_Loggers::notice("404 Not Found");
+        SyL_Response::setStatusHeader('404');
+        
+        echo "404 Not Found";
+        exit;
+    }
+
     /**
      * Ķ̥顼
      * 
