@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006-2007 k.watanabe
+ * Copyright (C) 2006-2008 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.7 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,9 +37,9 @@
  *
  * @package   SyL
  * @author    Koki Watanabe <k.watanabe@syl.jp>
- * @copyright 2006-2007 k.watanabe
+ * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Action.php,v 1.7 2007/12/29 09:15:29 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Action.php,v 1.8 2008/01/15 09:19:03 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Action
@@ -55,6 +55,17 @@ class SyL_Action
     {
     }
 
+    /**
+     * ¹ԥǥեȥ᥽å
+     *
+     * @access public
+     * @param object ǡ֥
+     * @param object ƥȥ֥
+     */
+    function execute(&$data, &$context)
+    {
+    }
+
     /**
      * ᥽åɼ¹Ը˼¹Ԥ᥽å
      * 
