@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.29 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.30 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Error.php,v 1.29 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Error.php,v 1.30 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Error
@@ -185,6 +185,28 @@ class SyL_Error
         trigger_error($error_string, $error_type);
     }
 
+    /**
+     * 404 Not Found ɽ
+     *
+     * @static
+     * @access public
+     */
+    function forward404()
+    {
+        $error =& SyL_Error::getInstance();
+        $error->forward404Detail();
+        exit;
+    }
+
+    /**
+     * 404 Not Found ɽ
+     *
+     * @access public
+     */
+    function forward404Detail()
+    {
+    }
+
     /**
      * 顼ϥɥ顼μ
      *
