@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.7 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Loader.php,v 1.6 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Loader.php,v 1.7 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Loader
@@ -56,13 +56,14 @@ class SyL_Loader
      * @access public
      * @param string ɥե
      * @param bool 顼٥ȥե饰
+     * @param string ĥ
      * @return mixed include_once
      */
-    function lib($path, $trigger=true)
+    function lib($path, $trigger=true, $ext='php')
     {
         $classname = __CLASS__;
 
-        $tmp_path = call_user_func(array($classname, 'convertPath'), $path);
+        $tmp_path = call_user_func(array($classname, 'convertPath'), $path, $ext);
         // ץꥱ饤֥ǥ쥯ȥ
         $base1 = SYL_APP_LIB_DIR . $tmp_path;
         if (is_file($base1)) {
@@ -74,7 +75,7 @@ class SyL_Loader
             return call_user_func(array($classname, 'load'), $base2);
         }
 
-        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path);
+        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path, $ext);
         // ɸ饤֥ǥ쥯ȥSyLѥѥ
         $base3 = SYL_INCLUDE_DIR . '/lib' . $tmp_path;
         if (is_file($base3)) {
@@ -95,13 +96,14 @@ class SyL_Loader
      * @access public
      * @param string ɥե
      * @param bool 顼٥ȥե饰
+     * @param string ĥ
      * @return mixed include_once
      */
-    function fw($path, $trigger=true)
+    function fw($path, $trigger=true, $ext='php')
     {
         $classname = __CLASS__;
 
-        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path);
+        $tmp_path = call_user_func(array($classname, 'convertPathSyL'), $path, $ext);
         $base1 = SYL_INCLUDE_DIR . "/framework" . $tmp_path;
         if (is_file($base1)) {
             return call_user_func(array($classname, 'load'), $base1);
@@ -150,18 +152,19 @@ class SyL_Loader
      * @static
      * @access public
      * @param string ѥ
+     * @param string ĥ
      * @return string Ѵѥ
      */
-    function convertPathSyL($path)
+    function convertPathSyL($path, $ext='php')
     {
         $path      = array_map('ucfirst', explode('.', $path));
         $classname = 'SyL_' . implode('', $path);
         array_pop($path); // ե
         $path = implode('/', $path);
         if ($path == '') {
-            return "/{$classname}.php";
+            return "/{$classname}.{$ext}";
         } else {
-            return "/{$path}/{$classname}.php";
+            return "/{$path}/{$classname}.{$ext}";
         }
     }
 
