@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.17 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.18 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.17 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.18 2008/02/02 14:40:44 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
@@ -152,15 +152,9 @@ class SyL_Response
         if (!headers_sent() && (ob_get_level() > 0)) {
             ob_clean();
         }
-
-        SyL_Response::setStatusHeader('404');
-        SyL_Loggers::notice("404 Not Found");
-        if (SYL_ENV_TYPE == 'web') {
-            include_once SYL_ERROR_FORWARD_FILE_404;
-        } else {
-            echo "File Not Found";
-        }
-        exit;
+        // ե졼Ȥɽ
+        SyL_Error::forward404();
+        // λ
     }
 
     /**
