@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.17 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -35,7 +35,7 @@
 /**
  * ڸ̥饹δ쥯饹
  */
-require_once 'SyL_FormElement.php';
+require_once dirname(__FILE__) . '/Form/SyL_FormElement.php';
 /**
  * ڥ饹
  */
@@ -48,7 +48,7 @@ require_once 'SyL_Validation.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Form.php,v 1.16 2008/01/15 09:19:03 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Form.php,v 1.17 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Form
@@ -515,9 +515,9 @@ class SyL_Form
 
         // Хǡ
         $validation  = '';
-        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_FormErrors.js');
-        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_Validator.js');
-        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_Validation.js');
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_JsClientFormErrors.js');
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_JsClientValidator.js');
+        $validation .= file_get_contents(dirname(__FILE__) . '/JsClient/SyL_JsClientValidation.js');
         // ƥå᥽å
         $funcs   = '';
         $checker = '';
