@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.16 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.17 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once dirname(__FILE__) . '/Mail/SyL_MailMessage.php';
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Mail.php,v 1.16 2008/01/20 15:09:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Mail.php,v 1.17 2008/02/02 14:40:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Mail
@@ -62,7 +62,7 @@ class SyL_Mail
      * @access protected
      * @var int
      */
-    var $port = 0;
+    var $port = '';
     /**
      * 桼̾
      *
@@ -126,8 +126,10 @@ class SyL_Mail
     /**
      * ᡼饹Υ󥹥󥹼
      *
+     * @static
      * @access public
      * @param string ᡼
+     * @return object ᡼֥
      */
     function &factorySend($type='Default')
     {
@@ -142,8 +144,10 @@ class SyL_Mail
     /**
      * ᡼饹Υ󥹥󥹼
      *
+     * @static
      * @access public
      * @param string ᡼
+     * @return object ᡼֥
      */
     function &factoryReceive($type='Pop3')
     {
