@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.7 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.8 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.7 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_UtilUseragent.php,v 1.8 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_UtilUserAgent
@@ -64,9 +64,10 @@ class SyL_UtilUserAgent
       'Windows NT 5.1'  => 'Windows XP',
       'Windows NT 5.01' => 'Windows 2000 (Service Pack 1)',
       'Windows NT 5.0'  => 'Windows 2000',
+      'Windows 2000'    => 'Windows 2000',
       'Windows NT 4.0'  => 'Windows NT 4.0',
       'winnt4.0'        => 'Windows NT 4.0',
-      'winnt 4.0'       => 'Windows NT',
+      'winnt 4.0'       => 'Windows NT 4.0',
       'winnt'           => 'Windows NT',
       'windows 98'      => 'Windows 98',
       'win98'           => 'Windows 98',
@@ -82,8 +83,7 @@ class SyL_UtilUserAgent
       'Debian'          => 'Debian Linux',
       'SunOS'           => 'Sun Solaris',
       'beos'            => 'BeOS',
-      'aix'             => 'AIX',
-      'irix'            => 'Irix',
+      'Asianux'         => 'Asianux',
       'hp-ux'           => 'HP-UX',
       'netbsd'          => 'NetBSD',
       'openbsd'         => 'OpenBSD',
@@ -92,6 +92,8 @@ class SyL_UtilUserAgent
       'Ubuntu'          => 'Ubuntu Linux',
       'Mandriva'        => 'Mandriva Linux',
       'Red Hat'         => 'Red Hat Linux',
+      'aix'             => 'AIX',
+      'irix'            => 'Irix',
       'gnu'             => 'GNU/Linux',
       'vine'            => 'Vine Linux',
       'linux'           => 'Linux',
@@ -130,6 +132,7 @@ class SyL_UtilUserAgent
       'hotjava'           => 'HotJava',
       'Lynx'              => 'Lynx',
       'jig browser'       => 'jig browser',
+      'Iceweasel'         => 'Iceweasel',
 
       'sharp pda browser' => 'ZAURUS',
       'AVE-Front'         => 'AVE-Front',
@@ -268,8 +271,11 @@ class SyL_UtilUserAgent
     function getPlatform()
     {
         foreach ($this->platforms as $key => $value) {
-            if (stristr($this->user_agent, $key) !== false) {
-                return $value;
+            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9\.]+)?([ |;])?.*/i';
+            if (preg_match($reg, $this->user_agent, $matches)) {
+            //if (stristr($this->user_agent, $key) !== false) {
+                return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
+                //return $value;
             }
         }
         return null;
@@ -284,7 +290,7 @@ class SyL_UtilUserAgent
     function getBrowser()
     {
         foreach ($this->browsers as $key => $value) {
-            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9\.\/]+)?.*/i';
+            $reg = '/' . preg_quote($key, '/') . '[ |\/]?([0-9a-zA-Z\-\.\/]+)?[ |;]?.*/i';
             if (preg_match($reg, $this->user_agent, $matches)) {
                 return isset($matches[1]) ? $value . ' ' . $matches[1] : $value;
             }
