@@ -27,7 +27,7 @@
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.3 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -51,7 +51,7 @@ require_once dirname(__FILE__) . '/Yahoo_co_jp/SyL_WebServiceYahoo_co_jpResponse
  * @author    Koki Watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2008 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.2 2008/03/01 05:01:22 seasonstream Exp $
+ * @version   CVS: $Id: SyL_WebServiceYahoo_co_jp.php,v 1.3 2008/03/29 06:11:46 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_WebServiceYahoo_co_jp extends SyL_WebService
@@ -276,6 +276,20 @@ class SyL_WebServiceYahoo_co_jp extends SyL_WebService
         return $request;
     }
 
+    /**
+     * WEBӥꥯȥ֥ȤʹٱWebӥ
+     * 
+     * @access public
+     * @return object WEBӥꥯȥ֥ȡʹٱWebӥ
+     */
+    function &createKouseiRequest()
+    {
+        $class_name = 'SyL_WebServiceTextKouseiRequest';
+        include_once dirname(__FILE__) . '/Yahoo_co_jp/Text/Kousei/' . $class_name . '.php';
+        $request =& new $class_name();
+        return $request;
+    }
+
     // -----------------------------------------------------
     // Yahoo!ťʥ
     // -----------------------------------------------------
